@@ -5,9 +5,9 @@ import sys
 HWT_KEYWORDS = keyword.kwlist + [
     # imports
     'hwt', 'Unit', "Param", "Signal",
-    "power", "Concat", "If", "Switch",
-    "HArray", "HArrayVal", "Bits", "INT", "SLICE",
-    "HEnum", "SliceVal", "_",
+    "Concat", "If", "Switch",
+    "HArray", "HArrayVal", "Bits", "INT", "SLICE", "FLOAT64",
+    "HEnum", "SliceVal", "_", "rename_signal",
 ]
 
 if sys.version_info[0] <= 2:
