@@ -23,6 +23,7 @@ class ToVerilog2005Stm(ToVerilog2005Expr):
     def __init__(self, out_stream):
         super(ToVerilog2005Stm, self).__init__(out_stream)
         self.top_stm = None
+        self.is_in_loop_spec = False
 
     def visit_iHdlStatement(self, stm):
         """
@@ -185,8 +186,8 @@ class ToVerilog2005Stm(ToVerilog2005Expr):
         """
         self.visit_doc(o)
         w = self.out.write
-        ts = self.top_stm 
-        if ts is o or (ts is not None and ts.in_preproc):
+        ts = self.top_stm
+        if not self.is_in_loop_spec and (ts is o or (ts is not None and ts.in_preproc)):
             w("assign ")
             self.visit_iHdlExpr(o.dst)
             w(" = ")
@@ -279,10 +280,19 @@ class ToVerilog2005Stm(ToVerilog2005Expr):
         else:
             init_stms = [o.init, ]
 
-        for is_last, stm in iter_with_last(init_stms):
-            self.visit_iHdlStatement(stm)
-            if not is_last:
-                w(", ")
+        trnt = self._type_requires_nettype
+        in_in_loop_spec = self.is_in_loop_spec
+        try:
+            self._type_requires_nettype = False
+            self.is_in_loop_spec = True
+            for is_last, stm in iter_with_last(init_stms):
+                self.visit_iHdlStatement(stm)
+                if not is_last:
+                    w(", ")
+        finally:
+            self.is_in_loop_spec = in_in_loop_spec
+            self._type_requires_nettype = trnt
+
         w("; ")
         self.visit_iHdlExpr(o.cond)
         w("; ")
@@ -366,3 +376,24 @@ class ToVerilog2005Stm(ToVerilog2005Expr):
         self.visit_doc(o)
         self.out.write("break")
         return True
+
+    def visit_HdlStmThrow(self, o):
+        """
+        :type o: HdlStmThrow
+        """
+        raise ValueError("SystemVerilog does not have exceptions")
+
+    # [TODO] SV only
+    def visit_HdlImport(self, o):
+        """
+        :type o: HdlImport
+        """
+        self.visit_doc(o)
+        w = self.out.write
+        w("import ")
+        package, name = o.path
+        self.visit_iHdlExpr(package)
+        w("::")
+        self.visit_iHdlExpr(name)
+
+        return True
